/***************************************************************************
 * Copyright 2013 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.common;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import kieker.common.logging.Log;
import kieker.common.logging.LogFactory;

/**
 * This is a context listener, which will be activated during the initialization of the application. It initializes some environment properties, which are necessary
 * for the web application.<br>
 * </br>
 * 
 * The only environment property which is currently set by this listener is the property for the web application logger. This makes sure that later created analyses
 * use the correct logger, whose messages can be intercepted by this application. If this environment property is not set, the log entries of the analyses cannot be
 * shown in the corresponding control panel.
 * 
 * @author Nils Christian Ehmke
 */
public class EnvironmentLoaderListener implements ServletContextListener {

	private static final Log LOG = LogFactory.getLog(EnvironmentLoaderListener.class);

	/**
	 * Creates a new instance of this class. <b>Do not call this constructor manually. It will only be accessed by the servlet container.</b>
	 */
	public EnvironmentLoaderListener() {
		// No code necessary
	}

	@Override
	public void contextDestroyed(final ServletContextEvent event) {
		// No code necessary
	}

	@Override
	public void contextInitialized(final ServletContextEvent event) {
		// We have to use the logger before setting the environment property. This makes sure, that our own logger is not initialized with the web application
		// logger. All components which are created later use the correct logger though (they are loaded with another class loader and use another instance of the
		// logging factory class therefore).
		LOG.info("Starting Kieker.WebGUI environment initialization.");
		final long timeIn = System.currentTimeMillis();

		System.setProperty("kieker.common.logging.Log", "WEBGUI");

		final long timeOut = System.currentTimeMillis();
		final long timeDelta = timeOut - timeIn;

		LOG.info(String.format("Kieker.WebGUI environment initialized in %d ms.", timeDelta));
	}

}
